==> odin_1.8.1.orig.tar.gz: odin-1.8.1/tjutils/tjtest.h <==
/***************************************************************************
                          tjtest.h  -  description
                             -------------------
    begin                : Mon Dec 12 2005
    copyright            : (C) 2001 by Thies H. Jochimsen
    email                : jochimse@cns.mpg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TJTEST_H
#define TJTEST_H

#include <tjutils/tjstatic.h>
#include <tjutils/tjlabel.h>

/**
  * @addtogroup tjutils
  * @{
  */

#ifndef NO_UNIT_TEST

/**
  * Base class for unit tests. Derive from this, implement
  * the check() function and place a static instanve in the
  * source file to register it for the test run.
  */
class UnitTest : public StaticHandler<UnitTest>, public Labeled {

 public:

  static int check_all();

  static void init_static();
  static void destroy_static();

  static const char* get_compName();

 protected:

  UnitTest(const char* label);
  virtual ~UnitTest() {}

 private:

  virtual bool check() const = 0;

  static STD_list<UnitTest*>* tests;

};

#endif

/** @}
  */
#endif

==> odin_1.8.8.orig.tar.gz: odin-1.8.8/tjutils/tjtest.h <==
/***************************************************************************
                          tjtest.h  -  description
                             -------------------
    begin                : Mon Dec 12 2005
    copyright            : (C) 2000-2014 by Thies H. Jochimsen
    email                : thies@jochimsen.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TJTEST_H
#define TJTEST_H

#include <tjutils/tjstatic.h>
#include <tjutils/tjlabel.h>

/**
  * @addtogroup tjutils
  * @{
  */

#ifndef NO_UNIT_TEST

/**
  * Base class for unit tests. Derive from this, implement
  * the check() function and place a static instanve in the
  * source file to register it for the test run.
  */
class UnitTest : public StaticHandler<UnitTest>, public Labeled {

 public:

  static int check_all();

  static void init_static();
  static void destroy_static();

  static const char* get_compName();

 protected:

  UnitTest(const char* label);
  virtual ~UnitTest() {}

 private:

  virtual bool check() const = 0;

  static STD_list<UnitTest*>* tests;

};

#endif

/** @}
  */
#endif
